/* GDA Manager
 * Copyright (C) 1998,1999 Michael Lausch
 * Copyright (C) 2000 Rodrigo Moya
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#if !defined(__gnomedb_mgr_h__)
#  define __gnomedb_mgr_h__

#include "config.h"
#include <gnome-db.h>
#include <libgnome/gnome-i18n.h>

BEGIN_GNOME_DECLS

/*
 * Callbacks
 */
BonoboObject* manager_control_new (void);

/*
 * Data Sources
 */
void manager_dsn_init (GtkNotebook *notebook);

/*
 * Providers
 */
void manager_providers_init (GtkNotebook *notebook);

END_GNOME_DECLS

#endif
